@@ -24,7 +24,7 @@ class FloatSpinBoxArgs(CommonParameterWidgetArgs):
 
 
 class FloatSpinBox(CommonParameterWidget):
-    HIDE_DEFAULT_WIDGET = True
+    HIDE_DEFAULT_VALUE_WIDGET = True
     SET_DEFAULT_ON_INIT = True
 
     _WidgetArgsClass = FloatSpinBoxArgs
